@@ -6,8 +6,8 @@ import (
 	"fmt"
 	"path/filepath"
 
+	"dario.cat/mergo"
 	"github.com/helmfile/vals"
-	"github.com/imdario/mergo"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/environment"
