@@ -3,6 +3,9 @@ package envvar
 const (
 	DisableInsecureFeatures = "HELMFILE_DISABLE_INSECURE_FEATURES"
 
+	// use helm status to check if a release exists before installing it
+	UseHelmStatusToCheckReleaseExistence = "HELMFILE_USE_HELM_STATUS_TO_CHECK_RELEASE_EXISTENCE"
+
 	// TODO: Remove this function once Helmfile v0.x
 	SkipInsecureTemplateFunctions = "HELMFILE_SKIP_INSECURE_TEMPLATE_FUNCTIONS"
 
